@@ -213,9 +213,11 @@ gconf_cell_renderer_text_editing_done (GtkCellEditable *entry, GConfCellRenderer
 {
 	const gchar *path;
 	const gchar *new_text;
+	gboolean editing_canceled = FALSE;
 	GConfValue *value;
-	
-	if (GTK_ENTRY (entry)->editing_canceled)
+
+	g_object_get (entry, "editing-canceled", &editing_canceled, NULL);
+	if (editing_canceled != FALSE)
 		return;
 
 	path = g_object_get_data (G_OBJECT (entry), GCONF_CELL_RENDERER_TEXT_PATH);
@@ -454,15 +456,15 @@ gconf_cell_renderer_class_init (GConfCellRendererClass *klass)
 static void
 gconf_cell_renderer_init (GConfCellRenderer *renderer)
 {
-	GTK_CELL_RENDERER (renderer)->mode = GTK_CELL_RENDERER_MODE_ACTIVATABLE;
+	g_object_set (renderer,
+	              "mode", GTK_CELL_RENDERER_MODE_ACTIVATABLE,
+	              NULL);
 	
 	renderer->text_renderer = gtk_cell_renderer_text_new ();
-	g_object_ref (renderer->text_renderer);
-	gtk_object_sink (GTK_OBJECT (renderer->text_renderer));
+	g_object_ref_sink (renderer->text_renderer);
 
 	renderer->toggle_renderer = gtk_cell_renderer_toggle_new ();
-	g_object_ref (renderer->toggle_renderer);
-	gtk_object_sink (GTK_OBJECT (renderer->toggle_renderer));
+	g_object_ref_sink (renderer->toggle_renderer);
 }
 
 
